# notifphy

### Installation:
`pip install notiphy`

### Basic usage:
```python
import notify

notify.notify(title="test",content="hello world")

```
### Advanced usage:
```python
import notify
notify.notify(icon="Information",largeicon="Info",title="",content="",Visible="True",time="1000")
# icons are from [System.Drawing.SystemIcons]::
```
### Supported OS;
Currently only for windows
